robotpy-adi
===========

RobotPy wrappers for the following Analog Devices products:

* ADIS16448
* ADIS16470

.. note:: The RobotPy project is not associated with or endorsed by Analog
          Devices Inc. or FIRST Robotics Competition

Documentation
-------------

* `Installation <https://robotpy.readthedocs.io/en/stable/install/adi.html>`_
* `Python API Documentation <https://robotpy.readthedocs.io/projects/adi/en/stable/api.html>`_

Authors
-------

* ADIS16448 support contributed by `@picode98 <https://github.com/picode98>`_
* ADIS16470 support contributed by `@SHU-matic <https://github.com/SHU-matic>`_

License
-------

MIT License